@@ -32,8 +32,6 @@
 
 extern crate lazy_static;
 extern crate libc;
-#[macro_use]
-extern crate thiserror;
 
 pub mod dec;
 mod number;
